@@ -146,14 +146,13 @@ class ApiClient(object):
 
         _get, _post = get.copy(), post.copy()
 
+        get = dict((k, v) for k, v in get.iteritems() if v is not None)
         get.update({
             '_sign': self.sign(**get),
             '_api_id': self._api_id,
         })
         get.update(self.env.params)
 
-        get = dict((k, v) for k, v in get.iteritems() if k[0] != '_' or v)
-
         url = "%s%s?%s" % (self._api_endpoint, func.lstrip(), urllib.urlencode(get))
         request = urllib2.Request(url)
         if _post:
