@@ -228,6 +228,12 @@ class Shop(Service):
         """
         return self._callapi("shop/salons/countries")
 
+    def get_cash_salons_by_id(self, salon_id):
+        """
+        :rtype : Salon
+        """
+        return self._callapi("shop/salons/salon", get={"salon_id": salon_id})
+
     def get_cash_salons_by_city(self, city_id):
         """
         :rtype : list of Salon|Collection
